@@ -5,6 +5,7 @@
 Tests for L{idavoll.memory_storage} and L{idavoll.pgsql_storage}.
 """
 
+from zope.interface.verify import verifyObject
 from twisted.trial import unittest
 from twisted.words.protocols.jabber import jid
 from twisted.internet import defer
@@ -12,7 +13,7 @@ from twisted.words.xish import domish
 
 from wokkel import pubsub
 
-from idavoll import error
+from idavoll import error, iidavoll
 
 OWNER = jid.JID('owner@example.com')
 SUBSCRIBER = jid.JID('subscriber@example.com/Home')
@@ -20,17 +21,16 @@ SUBSCRIBER_NEW = jid.JID('new@example.com/Home')
 SUBSCRIBER_TO_BE_DELETED = jid.JID('to_be_deleted@example.com/Home')
 SUBSCRIBER_PENDING = jid.JID('pending@example.com/Home')
 PUBLISHER = jid.JID('publisher@example.com')
-ITEM = domish.Element((pubsub.NS_PUBSUB, 'item'), pubsub.NS_PUBSUB)
+ITEM = domish.Element((None, 'item'))
 ITEM['id'] = 'current'
 ITEM.addElement(('testns', 'test'), content=u'Test \u2083 item')
-ITEM_NEW = domish.Element((pubsub.NS_PUBSUB, 'item'), pubsub.NS_PUBSUB)
+ITEM_NEW = domish.Element((None, 'item'))
 ITEM_NEW['id'] = 'new'
 ITEM_NEW.addElement(('testns', 'test'), content=u'Test \u2083 item')
-ITEM_UPDATED = domish.Element((pubsub.NS_PUBSUB, 'item'), pubsub.NS_PUBSUB)
+ITEM_UPDATED = domish.Element((None, 'item'))
 ITEM_UPDATED['id'] = 'current'
 ITEM_UPDATED.addElement(('testns', 'test'), content=u'Test \u2084 item')
-ITEM_TO_BE_DELETED = domish.Element((pubsub.NS_PUBSUB, 'item'),
-                                    pubsub.NS_PUBSUB)
+ITEM_TO_BE_DELETED = domish.Element((None, 'item'))
 ITEM_TO_BE_DELETED['id'] = 'to-be-deleted'
 ITEM_TO_BE_DELETED.addElement(('testns', 'test'), content=u'Test \u2083 item')
 
@@ -40,359 +40,437 @@ def decode(object):
     return object
 
 
+
 class StorageTests:
 
     def _assignTestNode(self, node):
         self.node = node
 
+
     def setUp(self):
-        d = self.s.get_node('pre-existing')
+        d = self.s.getNode('pre-existing')
         d.addCallback(self._assignTestNode)
         return d
 
-    def testGetNode(self):
-        return self.s.get_node('pre-existing')
 
-    def testGetNonExistingNode(self):
-        d = self.s.get_node('non-existing')
+    def test_interfaceIStorage(self):
+        self.assertTrue(verifyObject(iidavoll.IStorage, self.s))
+
+
+    def test_interfaceINode(self):
+        self.assertTrue(verifyObject(iidavoll.INode, self.node))
+
+
+    def test_interfaceILeafNode(self):
+        self.assertTrue(verifyObject(iidavoll.ILeafNode, self.node))
+
+
+    def test_getNode(self):
+        return self.s.getNode('pre-existing')
+
+
+    def test_getNonExistingNode(self):
+        d = self.s.getNode('non-existing')
         self.assertFailure(d, error.NodeNotFound)
         return d
 
-    def testGetNodeIDs(self):
-        def cb(node_ids):
-            self.assertIn('pre-existing', node_ids)
-            self.assertNotIn('non-existing', node_ids)
 
-        return self.s.get_node_ids().addCallback(cb)
+    def test_getNodeIDs(self):
+        def cb(nodeIdentifiers):
+            self.assertIn('pre-existing', nodeIdentifiers)
+            self.assertNotIn('non-existing', nodeIdentifiers)
 
-    def testCreateExistingNode(self):
-        d = self.s.create_node('pre-existing', OWNER)
+        return self.s.getNodeIds().addCallback(cb)
+
+
+    def test_createExistingNode(self):
+        config = self.s.getDefaultConfiguration('leaf')
+        config['pubsub#node_type'] = 'leaf'
+        d = self.s.createNode('pre-existing', OWNER, config)
         self.assertFailure(d, error.NodeExists)
         return d
 
-    def testCreateNode(self):
+
+    def test_createNode(self):
         def cb(void):
-            d = self.s.get_node('new 1')
+            d = self.s.getNode('new 1')
             return d
 
-        d = self.s.create_node('new 1', OWNER)
+        config = self.s.getDefaultConfiguration('leaf')
+        config['pubsub#node_type'] = 'leaf'
+        d = self.s.createNode('new 1', OWNER, config)
         d.addCallback(cb)
         return d
 
-    def testDeleteNonExistingNode(self):
-        d = self.s.delete_node('non-existing')
+
+    def test_deleteNonExistingNode(self):
+        d = self.s.deleteNode('non-existing')
         self.assertFailure(d, error.NodeNotFound)
         return d
 
-    def testDeleteNode(self):
+
+    def test_deleteNode(self):
         def cb(void):
-            d = self.s.get_node('to-be-deleted')
+            d = self.s.getNode('to-be-deleted')
             self.assertFailure(d, error.NodeNotFound)
             return d
 
-        d = self.s.delete_node('to-be-deleted')
+        d = self.s.deleteNode('to-be-deleted')
         d.addCallback(cb)
         return d
 
-    def testGetAffiliations(self):
+
+    def test_getAffiliations(self):
         def cb(affiliations):
             self.assertIn(('pre-existing', 'owner'), affiliations)
 
-        d = self.s.get_affiliations(OWNER)
+        d = self.s.getAffiliations(OWNER)
         d.addCallback(cb)
         return d
 
-    def testGetSubscriptions(self):
+
+    def test_getSubscriptions(self):
         def cb(subscriptions):
-            self.assertIn(('pre-existing', SUBSCRIBER, 'subscribed'), subscriptions)
+            found = False
+            for subscription in subscriptions:
+                if (subscription.nodeIdentifier == 'pre-existing' and
+                    subscription.subscriber == SUBSCRIBER and
+                    subscription.state == 'subscribed'):
+                    found = True
+            self.assertTrue(found)
 
-        d = self.s.get_subscriptions(SUBSCRIBER)
+        d = self.s.getSubscriptions(SUBSCRIBER)
         d.addCallback(cb)
         return d
 
+
     # Node tests
 
-    def testGetType(self):
-        self.assertEqual(self.node.get_type(), 'leaf')
+    def test_getType(self):
+        self.assertEqual(self.node.getType(), 'leaf')
 
-    def testGetConfiguration(self):
-        config = self.node.get_configuration()
+
+    def test_getConfiguration(self):
+        config = self.node.getConfiguration()
         self.assertIn('pubsub#persist_items', config.iterkeys())
         self.assertIn('pubsub#deliver_payloads', config.iterkeys())
         self.assertEqual(config['pubsub#persist_items'], True)
         self.assertEqual(config['pubsub#deliver_payloads'], True)
 
-    def testSetConfiguration(self):
-        def get_config(node):
-            d = node.set_configuration({'pubsub#persist_items': False})
+
+    def test_setConfiguration(self):
+        def getConfig(node):
+            d = node.setConfiguration({'pubsub#persist_items': False})
             d.addCallback(lambda _: node)
             return d
 
-        def check_object_config(node):
-            config = node.get_configuration()
+        def checkObjectConfig(node):
+            config = node.getConfiguration()
             self.assertEqual(config['pubsub#persist_items'], False)
 
-        def get_node(void):
-            return self.s.get_node('to-be-reconfigured')
+        def getNode(void):
+            return self.s.getNode('to-be-reconfigured')
 
-        def check_storage_config(node):
-            config = node.get_configuration()
+        def checkStorageConfig(node):
+            config = node.getConfiguration()
             self.assertEqual(config['pubsub#persist_items'], False)
 
-        d = self.s.get_node('to-be-reconfigured')
-        d.addCallback(get_config)
-        d.addCallback(check_object_config)
-        d.addCallback(get_node)
-        d.addCallback(check_storage_config)
+        d = self.s.getNode('to-be-reconfigured')
+        d.addCallback(getConfig)
+        d.addCallback(checkObjectConfig)
+        d.addCallback(getNode)
+        d.addCallback(checkStorageConfig)
         return d
 
-    def testGetMetaData(self):
-        meta_data = self.node.get_meta_data()
-        for key, value in self.node.get_configuration().iteritems():
-            self.assertIn(key, meta_data.iterkeys())
-            self.assertEqual(value, meta_data[key])
-        self.assertIn('pubsub#node_type', meta_data.iterkeys())
-        self.assertEqual(meta_data['pubsub#node_type'], 'leaf')
 
-    def testGetAffiliation(self):
+    def test_getMetaData(self):
+        metaData = self.node.getMetaData()
+        for key, value in self.node.getConfiguration().iteritems():
+            self.assertIn(key, metaData.iterkeys())
+            self.assertEqual(value, metaData[key])
+        self.assertIn('pubsub#node_type', metaData.iterkeys())
+        self.assertEqual(metaData['pubsub#node_type'], 'leaf')
+
+
+    def test_getAffiliation(self):
         def cb(affiliation):
             self.assertEqual(affiliation, 'owner')
 
-        d = self.node.get_affiliation(OWNER)
+        d = self.node.getAffiliation(OWNER)
         d.addCallback(cb)
         return d
 
-    def testGetNonExistingAffiliation(self):
+
+    def test_getNonExistingAffiliation(self):
         def cb(affiliation):
             self.assertEqual(affiliation, None)
 
-        d = self.node.get_affiliation(SUBSCRIBER)
+        d = self.node.getAffiliation(SUBSCRIBER)
         d.addCallback(cb)
         return d
 
-    def testAddSubscription(self):
+
+    def test_addSubscription(self):
         def cb1(void):
-            return self.node.get_subscription(SUBSCRIBER_NEW)
+            return self.node.getSubscription(SUBSCRIBER_NEW)
 
-        def cb2(state):
-            self.assertEqual(state, 'pending')
+        def cb2(subscription):
+            self.assertEqual(subscription.state, 'pending')
 
-        d = self.node.add_subscription(SUBSCRIBER_NEW, 'pending')
+        d = self.node.addSubscription(SUBSCRIBER_NEW, 'pending', {})
         d.addCallback(cb1)
         d.addCallback(cb2)
         return d
 
-    def testAddExistingSubscription(self):
-        d = self.node.add_subscription(SUBSCRIBER, 'pending')
+
+    def test_addExistingSubscription(self):
+        d = self.node.addSubscription(SUBSCRIBER, 'pending', {})
         self.assertFailure(d, error.SubscriptionExists)
         return d
 
-    def testGetSubscription(self):
-        def cb(subscriptions):
-            self.assertEquals(subscriptions[0][1], 'subscribed')
-            self.assertEquals(subscriptions[1][1], 'pending')
-            self.assertEquals(subscriptions[2][1], None)
 
-        d = defer.DeferredList([self.node.get_subscription(SUBSCRIBER),
-                                self.node.get_subscription(SUBSCRIBER_PENDING),
-                                self.node.get_subscription(OWNER)])
+    def test_getSubscription(self):
+        def cb(subscriptions):
+            self.assertEquals(subscriptions[0].state, 'subscribed')
+            self.assertEquals(subscriptions[1].state, 'pending')
+            self.assertEquals(subscriptions[2], None)
+
+        d = defer.gatherResults([self.node.getSubscription(SUBSCRIBER),
+                                 self.node.getSubscription(SUBSCRIBER_PENDING),
+                                 self.node.getSubscription(OWNER)])
         d.addCallback(cb)
         return d
 
-    def testRemoveSubscription(self):
-        return self.node.remove_subscription(SUBSCRIBER_TO_BE_DELETED)
 
-    def testRemoveNonExistingSubscription(self):
-        d = self.node.remove_subscription(OWNER)
+    def test_removeSubscription(self):
+        return self.node.removeSubscription(SUBSCRIBER_TO_BE_DELETED)
+
+
+    def test_removeNonExistingSubscription(self):
+        d = self.node.removeSubscription(OWNER)
         self.assertFailure(d, error.NotSubscribed)
         return d
 
-    def testGetSubscribers(self):
+
+    def test_getNodeSubscriptions(self):
+        def extractSubscribers(subscriptions):
+            return [subscription.subscriber for subscription in subscriptions]
+
         def cb(subscribers):
             self.assertIn(SUBSCRIBER, subscribers)
             self.assertNotIn(SUBSCRIBER_PENDING, subscribers)
             self.assertNotIn(OWNER, subscribers)
 
-        d = self.node.get_subscribers()
+        d = self.node.getSubscriptions('subscribed')
+        d.addCallback(extractSubscribers)
         d.addCallback(cb)
         return d
 
-    def testIsSubscriber(self):
+
+    def test_isSubscriber(self):
         def cb(subscribed):
             self.assertEquals(subscribed[0][1], True)
             self.assertEquals(subscribed[1][1], True)
             self.assertEquals(subscribed[2][1], False)
             self.assertEquals(subscribed[3][1], False)
 
-        d = defer.DeferredList([self.node.is_subscribed(SUBSCRIBER),
-                                self.node.is_subscribed(SUBSCRIBER.userhostJID()),
-                                self.node.is_subscribed(SUBSCRIBER_PENDING),
-                                self.node.is_subscribed(OWNER)])
+        d = defer.DeferredList([self.node.isSubscribed(SUBSCRIBER),
+                                self.node.isSubscribed(SUBSCRIBER.userhostJID()),
+                                self.node.isSubscribed(SUBSCRIBER_PENDING),
+                                self.node.isSubscribed(OWNER)])
         d.addCallback(cb)
         return d
 
-    def testStoreItems(self):
+
+    def test_storeItems(self):
         def cb1(void):
-            return self.node.get_items_by_id(['new'])
+            return self.node.getItemsById(['new'])
 
         def cb2(result):
-            self.assertEqual(result[0], decode(ITEM_NEW.toXml()))
+            self.assertEqual(ITEM_NEW.toXml(), result[0].toXml())
 
-        d = self.node.store_items([ITEM_NEW], PUBLISHER)
+        d = self.node.storeItems([ITEM_NEW], PUBLISHER)
         d.addCallback(cb1)
         d.addCallback(cb2)
         return d
 
-    def testStoreUpdatedItems(self):
+
+    def test_storeUpdatedItems(self):
         def cb1(void):
-            return self.node.get_items_by_id(['current'])
+            return self.node.getItemsById(['current'])
 
         def cb2(result):
-            self.assertEqual(result[0], decode(ITEM_UPDATED.toXml()))
+            self.assertEqual(ITEM_UPDATED.toXml(), result[0].toXml())
 
-        d = self.node.store_items([ITEM_UPDATED], PUBLISHER)
+        d = self.node.storeItems([ITEM_UPDATED], PUBLISHER)
         d.addCallback(cb1)
         d.addCallback(cb2)
         return d
 
-    def testRemoveItems(self):
+
+    def test_removeItems(self):
         def cb1(result):
-            self.assertEqual(result, ['to-be-deleted'])
-            return self.node.get_items_by_id(['to-be-deleted'])
+            self.assertEqual(['to-be-deleted'], result)
+            return self.node.getItemsById(['to-be-deleted'])
 
         def cb2(result):
-            self.assertEqual(len(result), 0)
+            self.assertEqual(0, len(result))
 
-        d = self.node.remove_items(['to-be-deleted'])
+        d = self.node.removeItems(['to-be-deleted'])
         d.addCallback(cb1)
         d.addCallback(cb2)
         return d
 
-    def testRemoveNonExistingItems(self):
-        def cb(result):
-            self.assertEqual(result, [])
 
-        d = self.node.remove_items(['non-existing'])
+    def test_removeNonExistingItems(self):
+        def cb(result):
+            self.assertEqual([], result)
+
+        d = self.node.removeItems(['non-existing'])
         d.addCallback(cb)
         return d
 
-    def testGetItems(self):
-        def cb(result):
-            self.assertIn(decode(ITEM.toXml()), result)
 
-        d = self.node.get_items()
+    def test_getItems(self):
+        def cb(result):
+            items = [item.toXml() for item in result]
+            self.assertIn(ITEM.toXml(), items)
+
+        d = self.node.getItems()
         d.addCallback(cb)
         return d
 
-    def testLastItem(self):
-        def cb(result):
-            self.assertEqual([decode(ITEM.toXml())], result)
 
-        d = self.node.get_items(1)
+    def test_lastItem(self):
+        def cb(result):
+            self.assertEqual(1, len(result))
+            self.assertEqual(ITEM.toXml(), result[0].toXml())
+
+        d = self.node.getItems(1)
         d.addCallback(cb)
         return d
 
-    def testGetItemsById(self):
-        def cb(result):
-            self.assertEqual(len(result), 1)
 
-        d = self.node.get_items_by_id(['current'])
+    def test_getItemsById(self):
+        def cb(result):
+            self.assertEqual(1, len(result))
+
+        d = self.node.getItemsById(['current'])
         d.addCallback(cb)
         return d
 
-    def testGetNonExistingItemsById(self):
-        def cb(result):
-            self.assertEqual(len(result), 0)
 
-        d = self.node.get_items_by_id(['non-existing'])
+    def test_getNonExistingItemsById(self):
+        def cb(result):
+            self.assertEqual(0, len(result))
+
+        d = self.node.getItemsById(['non-existing'])
         d.addCallback(cb)
         return d
 
-    def testPurge(self):
+
+    def test_purge(self):
         def cb1(node):
             d = node.purge()
             d.addCallback(lambda _: node)
             return d
 
         def cb2(node):
-            return node.get_items()
+            return node.getItems()
 
         def cb3(result):
             self.assertEqual([], result)
 
-        d = self.s.get_node('to-be-purged')
+        d = self.s.getNode('to-be-purged')
         d.addCallback(cb1)
         d.addCallback(cb2)
         d.addCallback(cb3)
         return d
 
-    def testGetNodeAffilatiations(self):
+
+    def test_getNodeAffilatiations(self):
         def cb1(node):
-            return node.get_affiliations()
+            return node.getAffiliations()
 
         def cb2(affiliations):
             affiliations = dict(((a[0].full(), a[1]) for a in affiliations))
             self.assertEquals(affiliations[OWNER.full()], 'owner')
 
-        d = self.s.get_node('pre-existing')
+        d = self.s.getNode('pre-existing')
         d.addCallback(cb1)
         d.addCallback(cb2)
         return d
 
 
+
 class MemoryStorageStorageTestCase(unittest.TestCase, StorageTests):
 
     def setUp(self):
-        from idavoll.memory_storage import Storage, LeafNode, Subscription, \
-                                           default_config
+        from idavoll.memory_storage import Storage, PublishedItem, LeafNode
+        from idavoll.memory_storage import Subscription
+
+        defaultConfig = Storage.defaultConfig['leaf']
+
         self.s = Storage()
         self.s._nodes['pre-existing'] = \
-                LeafNode('pre-existing', OWNER, default_config)
+                LeafNode('pre-existing', OWNER, defaultConfig)
         self.s._nodes['to-be-deleted'] = \
                 LeafNode('to-be-deleted', OWNER, None)
         self.s._nodes['to-be-reconfigured'] = \
-                LeafNode('to-be-reconfigured', OWNER, default_config)
+                LeafNode('to-be-reconfigured', OWNER, defaultConfig)
         self.s._nodes['to-be-purged'] = \
                 LeafNode('to-be-purged', OWNER, None)
 
         subscriptions = self.s._nodes['pre-existing']._subscriptions
-        subscriptions[SUBSCRIBER.full()] = Subscription('subscribed')
+        subscriptions[SUBSCRIBER.full()] = Subscription('pre-existing',
+                                                        SUBSCRIBER,
+                                                        'subscribed')
         subscriptions[SUBSCRIBER_TO_BE_DELETED.full()] = \
-                Subscription('subscribed')
+                Subscription('pre-existing', SUBSCRIBER_TO_BE_DELETED,
+                             'subscribed')
         subscriptions[SUBSCRIBER_PENDING.full()] = \
-                Subscription('pending')
+                Subscription('pre-existing', SUBSCRIBER_PENDING,
+                             'pending')
 
-        item = (decode(ITEM_TO_BE_DELETED.toXml()), PUBLISHER)
+        item = PublishedItem(ITEM_TO_BE_DELETED, PUBLISHER)
         self.s._nodes['pre-existing']._items['to-be-deleted'] = item
         self.s._nodes['pre-existing']._itemlist.append(item)
         self.s._nodes['to-be-purged']._items['to-be-deleted'] = item
         self.s._nodes['to-be-purged']._itemlist.append(item)
-        item = (decode(ITEM.toXml()), PUBLISHER)
+        item = PublishedItem(ITEM, PUBLISHER)
         self.s._nodes['pre-existing']._items['current'] = item
         self.s._nodes['pre-existing']._itemlist.append(item)
 
         return StorageTests.setUp(self)
 
 
+
 class PgsqlStorageStorageTestCase(unittest.TestCase, StorageTests):
-    def _callSuperSetUp(self, void):
-        return StorageTests.setUp(self)
 
     def setUp(self):
         from idavoll.pgsql_storage import Storage
-        self.s = Storage('ralphm', 'pubsub_test')
-        self.s._dbpool.start()
-        d = self.s._dbpool.runInteraction(self.init)
-        d.addCallback(self._callSuperSetUp)
+        from twisted.enterprise import adbapi
+        self.dbpool = adbapi.ConnectionPool('pyPgSQL.PgSQL',
+                                            database='pubsub_test',
+                                            cp_reconnect=True,
+                                            client_encoding='utf-8',
+                                            )
+        self.s = Storage(self.dbpool)
+        self.dbpool.start()
+        d = self.dbpool.runInteraction(self.init)
+        d.addCallback(lambda _: StorageTests.setUp(self))
         return d
 
-    def tearDownClass(self):
-        #return self.s._dbpool.runInteraction(self.cleandb)
-        pass
+
+    def tearDown(self):
+        return self.dbpool.runInteraction(self.cleandb)
+
 
     def init(self, cursor):
         self.cleandb(cursor)
-        cursor.execute("""INSERT INTO nodes (node) VALUES ('pre-existing')""")
+        cursor.execute("""INSERT INTO nodes
+                          (node, node_type, persist_items)
+                          VALUES ('pre-existing', 'leaf', TRUE)""")
         cursor.execute("""INSERT INTO nodes (node) VALUES ('to-be-deleted')""")
         cursor.execute("""INSERT INTO nodes (node) VALUES ('to-be-reconfigured')""")
         cursor.execute("""INSERT INTO nodes (node) VALUES ('to-be-purged')""")
@@ -400,15 +478,15 @@ class PgsqlStorageStorageTestCase(unittest.TestCase, StorageTests):
                        OWNER.userhost())
         cursor.execute("""INSERT INTO affiliations
                           (node_id, entity_id, affiliation)
-                          SELECT nodes.id, entities.id, 'owner'
+                          SELECT node_id, entity_id, 'owner'
                           FROM nodes, entities
                           WHERE node='pre-existing' AND jid=%s""",
                        OWNER.userhost())
         cursor.execute("""INSERT INTO entities (jid) VALUES (%s)""",
                        SUBSCRIBER.userhost())
         cursor.execute("""INSERT INTO subscriptions
-                          (node_id, entity_id, resource, subscription)
-                          SELECT nodes.id, entities.id, %s, 'subscribed'
+                          (node_id, entity_id, resource, state)
+                          SELECT node_id, entity_id, %s, 'subscribed'
                           FROM nodes, entities
                           WHERE node='pre-existing' AND jid=%s""",
                        (SUBSCRIBER.resource,
@@ -416,8 +494,8 @@ class PgsqlStorageStorageTestCase(unittest.TestCase, StorageTests):
         cursor.execute("""INSERT INTO entities (jid) VALUES (%s)""",
                        SUBSCRIBER_TO_BE_DELETED.userhost())
         cursor.execute("""INSERT INTO subscriptions
-                          (node_id, entity_id, resource, subscription)
-                          SELECT nodes.id, entities.id, %s, 'subscribed'
+                          (node_id, entity_id, resource, state)
+                          SELECT node_id, entity_id, %s, 'subscribed'
                           FROM nodes, entities
                           WHERE node='pre-existing' AND jid=%s""",
                        (SUBSCRIBER_TO_BE_DELETED.resource,
@@ -425,8 +503,8 @@ class PgsqlStorageStorageTestCase(unittest.TestCase, StorageTests):
         cursor.execute("""INSERT INTO entities (jid) VALUES (%s)""",
                        SUBSCRIBER_PENDING.userhost())
         cursor.execute("""INSERT INTO subscriptions
-                          (node_id, entity_id, resource, subscription)
-                          SELECT nodes.id, entities.id, %s, 'pending'
+                          (node_id, entity_id, resource, state)
+                          SELECT node_id, entity_id, %s, 'pending'
                           FROM nodes, entities
                           WHERE node='pre-existing' AND jid=%s""",
                        (SUBSCRIBER_PENDING.resource,
@@ -435,25 +513,26 @@ class PgsqlStorageStorageTestCase(unittest.TestCase, StorageTests):
                        PUBLISHER.userhost())
         cursor.execute("""INSERT INTO items
                           (node_id, publisher, item, data, date)
-                          SELECT nodes.id, %s, 'to-be-deleted', %s,
+                          SELECT node_id, %s, 'to-be-deleted', %s,
                                  now() - interval '1 day'
                           FROM nodes
                           WHERE node='pre-existing'""",
                        (PUBLISHER.userhost(),
                         ITEM_TO_BE_DELETED.toXml()))
         cursor.execute("""INSERT INTO items (node_id, publisher, item, data)
-                          SELECT nodes.id, %s, 'to-be-deleted', %s
+                          SELECT node_id, %s, 'to-be-deleted', %s
                           FROM nodes
                           WHERE node='to-be-purged'""",
                        (PUBLISHER.userhost(),
                         ITEM_TO_BE_DELETED.toXml()))
         cursor.execute("""INSERT INTO items (node_id, publisher, item, data)
-                          SELECT nodes.id, %s, 'current', %s
+                          SELECT node_id, %s, 'current', %s
                           FROM nodes
                           WHERE node='pre-existing'""",
                        (PUBLISHER.userhost(),
                         ITEM.toXml()))
 
+
     def cleandb(self, cursor):
         cursor.execute("""DELETE FROM nodes WHERE node in
                           ('non-existing', 'pre-existing', 'to-be-deleted',
