@@ -1,9 +1,12 @@
 # Copyright (c) 2003-2008 Ralph Meijer
 # See LICENSE for details.
 
-from twisted.scripts.mktap import _tapHelper
+try:
+    from twisted.application.service import ServiceMaker
+except ImportError:
+    from twisted.scripts.mktap import _tapHelper as ServiceMaker
 
-Idavoll = _tapHelper(
+Idavoll = ServiceMaker(
         "Idavoll HTTP",
         "idavoll.tap_http",
         "Jabber Publish-Subscribe Service Component with HTTP gateway",
